@@ -10,6 +10,7 @@ import sys
 
 from zrb.config.llm_config import llm_config
 from zrb.context.any_context import AnyContext
+from zrb.util.cli.markdown import render_markdown
 from zrb.util.cli.style import stylize_blue, stylize_bold_yellow, stylize_faint
 from zrb.util.string.conversion import to_boolean
 
@@ -34,7 +35,7 @@ async def read_user_prompt(ctx: AnyContext) -> str:
         # Get user input based on mode
         if not multiline_mode:
             ctx.print("💬 >>", plain=True)
-        user_input = await _read_next_line(is_tty, reader, ctx)
+        user_input = await _read_next_line(reader, ctx)
         if not multiline_mode:
             ctx.print("", plain=True)
         # Handle user input
@@ -105,12 +106,13 @@ def _show_info(ctx: AnyContext):
                 _show_command("/modes", "Show current modes"),
                 _show_subcommand("<mode1,mode2,..>", "Set current modes"),
                 _show_command("/yolo", "Get current YOLO mode"),
-                _show_subcommand("<true|false>", "Set YOLO mode to true/false"),
+                _show_subcommand("<true|false|list-of-tools>", "Set YOLO mode"),
                 _show_command("/help", "Show this message"),
             ]
         ),
         plain=True,
     )
+    ctx.print("", plain=True)
 
 
 def _show_command(command: str, description: str) -> str:
@@ -157,9 +159,11 @@ async def _setup_input_reader(is_interactive: bool):
     return reader
 
 
-async def _read_next_line(is_interactive: bool, reader, ctx: AnyContext) -> str:
+async def _read_next_line(reader, ctx: AnyContext) -> str:
     """Reads one line of input using the provided reader."""
-    if is_interactive:
+    from prompt_toolkit import PromptSession
+
+    if isinstance(reader, PromptSession):
         return await reader.prompt_async()
 
     line_bytes = await reader.readline()
@@ -175,7 +179,7 @@ async def _trigger_ask_and_wait_for_result(
     ctx: AnyContext,
     user_prompt: str,
     modes: str,
-    yolo_mode: bool,
+    yolo_mode: bool | str,
     previous_session_name: str | None = None,
     start_new: bool = False,
 ) -> str | None:
@@ -197,27 +201,13 @@ async def _trigger_ask_and_wait_for_result(
         ctx, user_prompt, modes, yolo_mode, previous_session_name, start_new
     )
     result = await _wait_ask_result(ctx)
-    md_result = _render_markdown(result) if result is not None else ""
+    md_result = render_markdown(result) if result is not None else ""
     ctx.print("\n🤖 >>", plain=True)
     ctx.print(md_result, plain=True)
     ctx.print("", plain=True)
     return result
 
 
-def _render_markdown(markdown_text: str) -> str:
-    """
-    Renders Markdown to a string, ensuring link URLs are visible.
-    """
-    from rich.console import Console
-    from rich.markdown import Markdown
-
-    console = Console()
-    markdown = Markdown(markdown_text, hyperlinks=False)
-    with console.capture() as capture:
-        console.print(markdown)
-    return capture.get()
-
-
 def get_llm_ask_input_mapping(callback_ctx: AnyContext):
     """
     Generates the input mapping for the LLM ask task from the callback context.
@@ -249,7 +239,7 @@ async def _trigger_ask(
     ctx: AnyContext,
     user_prompt: str,
     modes: str,
-    yolo_mode: bool,
+    yolo_mode: bool | str,
     previous_session_name: str | None = None,
     start_new: bool = False,
 ):
