@@ -3,27 +3,9 @@ import time
 from collections import deque
 from typing import Callable
 
-import tiktoken
-
 from zrb.config.config import CFG
 
 
-def _estimate_token(text: str) -> int:
-    """
-    Estimates the number of tokens in a given text.
-    Tries to use the 'gpt-4o' model's tokenizer for an accurate count.
-    If the tokenizer is unavailable (e.g., due to network issues),
-    it falls back to a heuristic of 4 characters per token.
-    """
-    try:
-        # Primary method: Use tiktoken for an accurate count
-        enc = tiktoken.encoding_for_model("gpt-4o")
-        return len(enc.encode(text))
-    except Exception:
-        # Fallback method: Heuristic (4 characters per token)
-        return len(text) // 4
-
-
 class LLMRateLimiter:
     """
     Helper class to enforce LLM API rate limits and throttling.
@@ -36,13 +18,15 @@ class LLMRateLimiter:
         max_tokens_per_minute: int | None = None,
         max_tokens_per_request: int | None = None,
         throttle_sleep: float | None = None,
-        token_counter_fn: Callable[[str], int] | None = None,
+        use_tiktoken: bool | None = None,
+        tiktoken_encodeing_name: str | None = None,
     ):
         self._max_requests_per_minute = max_requests_per_minute
         self._max_tokens_per_minute = max_tokens_per_minute
         self._max_tokens_per_request = max_tokens_per_request
         self._throttle_sleep = throttle_sleep
-        self._token_counter_fn = token_counter_fn
+        self._use_tiktoken = use_tiktoken
+        self._tiktoken_encoding_name = tiktoken_encodeing_name
         self.request_times = deque()
         self.token_times = deque()
 
@@ -71,10 +55,16 @@ class LLMRateLimiter:
         return CFG.LLM_THROTTLE_SLEEP
 
     @property
-    def count_token(self) -> Callable[[str], int]:
-        if self._token_counter_fn is not None:
-            return self._token_counter_fn
-        return _estimate_token
+    def use_tiktoken(self) -> bool:
+        if self._use_tiktoken is not None:
+            return self._use_tiktoken
+        return CFG.USE_TIKTOKEN
+
+    @property
+    def tiktoken_encoding_name(self) -> str:
+        if self._tiktoken_encoding_name is not None:
+            return self._tiktoken_encoding_name
+        return CFG.TIKTOKEN_ENCODING_NAME
 
     def set_max_requests_per_minute(self, value: int):
         self._max_requests_per_minute = value
@@ -88,24 +78,43 @@ class LLMRateLimiter:
     def set_throttle_sleep(self, value: float):
         self._throttle_sleep = value
 
-    def set_token_counter_fn(self, fn: Callable[[str], int]):
-        self._token_counter_fn = fn
+    def count_token(self, prompt: str) -> int:
+        if not self.use_tiktoken:
+            return self._fallback_count_token(prompt)
+        try:
+            import tiktoken
+
+            enc = tiktoken.get_encoding(self.tiktoken_encoding_name)
+            return len(enc.encode(prompt))
+        except Exception:
+            return self._fallback_count_token(prompt)
+
+    def _fallback_count_token(self, prompt: str) -> int:
+        return len(prompt) // 4
 
     def clip_prompt(self, prompt: str, limit: int) -> str:
-        token_count = self.count_token(prompt)
-        if token_count <= limit:
-            return prompt
-        while token_count > limit:
-            prompt_parts = prompt.split(" ")
-            last_part_index = len(prompt_parts) - 2
-            clipped_prompt = " ".join(prompt_parts[:last_part_index])
-            clipped_prompt += "(Content clipped...)"
-            token_count = self.count_token(clipped_prompt)
-            if token_count < limit:
-                return clipped_prompt
-        return prompt[:limit]
+        if not self.use_tiktoken:
+            return self._fallback_clip_prompt(prompt, limit)
+        try:
+            import tiktoken
 
-    async def throttle(self, prompt: str):
+            enc = tiktoken.get_encoding("cl100k_base")
+            tokens = enc.encode(prompt)
+            if len(tokens) <= limit:
+                return prompt
+            truncated = tokens[: limit - 3]
+            clipped_text = enc.decode(truncated)
+            return clipped_text + "..."
+        except Exception:
+            return self._fallback_clip_prompt(prompt, limit)
+
+    def _fallback_clip_prompt(self, prompt: str, limit: int) -> str:
+        char_limit = limit * 4 if limit * 4 <= 10 else limit * 4 - 10
+        return prompt[:char_limit] + "..."
+
+    async def throttle(
+        self, prompt: str, throttle_notif_callback: Callable | None = None
+    ):
         now = time.time()
         tokens = self.count_token(prompt)
         # Clean up old entries
@@ -123,6 +132,8 @@ class LLMRateLimiter:
             len(self.request_times) >= self.max_requests_per_minute
             or sum(t for _, t in self.token_times) + tokens > self.max_tokens_per_minute
         ):
+            if throttle_notif_callback is not None:
+                throttle_notif_callback()
             await asyncio.sleep(self.throttle_sleep)
             now = time.time()
             while self.request_times and now - self.request_times[0] > 60:
